
import datetime

import django.test as test
import django_unixdatetimefield.tests.models as tm


class UnixDateTimeFieldTestCase(test.TestCase):

    def test_default_field(self):
        d = datetime.datetime(2015, 2, 21, 19, 38, 32, 209148)
        m = tm.DefaultField.objects.create(created_at=d)
        self.assertTrue(isinstance(m.created_at, datetime.datetime))
        self.assertEqual(m.created_at, d)

    def test_null_field(self):
        m = tm.NullField.objects.create()
        self.assertIsNone(m.created_at)

    def test_null_default_field(self):
        d = datetime.datetime(2015, 8, 23, 15, 38, 32, 209198)
        m = tm.NullDefaultField.objects.create()
        self.assertGreater(m.created_at, d)

    def test_blank_field(self):
        # NOTE(niklas9):
        # * blank values for Django field types such as DateTimeField or
        #   ForeignKey will be stored as NULL in the db, hence not asserting
        #   against empty string '' but rather Python's None-type below
        m = tm.BlankField.objects.create()
        self.assertIsNone(m.created_at)

    def test_autoset_field(self):
        m = tm.AutosetField.objects.create()
        self.assertIsNotNone(m.created_at)
        self.assertIsNotNone(m.updated_at)
        self.assertTrue(isinstance(m.created_at, datetime.datetime))
        self.assertTrue(isinstance(m.updated_at, datetime.datetime))
        m.save()
        self.assertGreater(m.updated_at, m.created_at)




import datetime

import django.db.models as models

import django_unixdatetimefield


class DefaultField(models.Model):
    created_at = django_unixdatetimefield.UnixDateTimeField()

class BlankField(models.Model):
    created_at = django_unixdatetimefield.UnixDateTimeField(null=True, blank=True)

class NullField(models.Model):
    created_at = django_unixdatetimefield.UnixDateTimeField(null=True)

class NullDefaultField(models.Model):
    created_at = django_unixdatetimefield.UnixDateTimeField(null=True,
                                            default=datetime.datetime.utcnow())

class AutosetField(models.Model):
    created_at = django_unixdatetimefield.UnixDateTimeField(auto_now_add=True)
    updated_at = django_unixdatetimefield.UnixDateTimeField(auto_now=True)



import datetime
import time

import django.db.models as models


class UnixDateTimeField(models.DateTimeField):

    # TODO(niklas9):
    # * should we take care of transforming between time zones in any way here ?
    # * get default datetime format from settings ?
    DEFAULT_DATETIME_FMT = '%Y-%m-%d %H:%M:%S'
    TZ_CONST = '+'
    # TODO(niklas9):
    # * metaclass below just for Django < 1.9, fix a if stmt for it?
    #__metaclass__ = models.SubfieldBase
    description = "Unix timestamp integer to datetime object"

    def get_internal_type(self):
        return 'PositiveIntegerField'

    def to_python(self, val):
        if val is None or isinstance(val, datetime.datetime):
            return val
        if isinstance(val, datetime.date):
            return datetime.datetime(val.year, val.month, val.day)
        elif self._is_string(val):
            # TODO(niklas9):
            # * not addressing time zone support as todo above for now
            if self.TZ_CONST in val:
                val = val.split(self.TZ_CONST)[0]
            return datetime.datetime.strptime(val, self.DEFAULT_DATETIME_FMT)
        else:
            return datetime.datetime.fromtimestamp(float(val))

    def _is_string(value, val):
        try:
            return isinstance(val, unicode)
        except NameError:
            return isinstance(val, str)

    def get_db_prep_value(self, val, *args, **kwargs):
        if val is None:
            if self.default == models.fields.NOT_PROVIDED:  return None
            return self.default
        return int(time.mktime(val.timetuple()))

    def value_to_string(self, obj):
        val = self._get_val_from_obj(obj)
        return self.to_python(val).strftime(self.DEFAULT_DATETIME_FMT)

    def from_db_value(self, val, *args, **kwargs):
        return self.to_python(val)




import setuptools

with open('README.md', 'r') as f:
    long_description = f.read()

setuptools.setup(
    name='django-unixdatetimefield',
    version='1.0.3',
    author='Niklas Andersson',
    author_email='nandersson900@gmail.com',
    description='UnixDateTimeField in Django',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/Niklas9/django-unixdatetimefield',
    zip_safe=False,
    install_requires=[
        'django',
    ],
    tests_require=[
        'psycopg2',
        'django-nose',
    ],
    packages=setuptools.find_packages(),
    #test_suite='runtests.runtests',
    include_package_data=True,
    classifiers=[
        "Framework :: Django",
        "Intended Audience :: Developers",
        "Intended Audience :: System Administrators",
        "Operating System :: OS Independent",
        "Topic :: Software Development"
    ],
)
